@@ -56,6 +56,8 @@ tinymce.addI18n('de_AT',{
 "OR": "oder",
 "Drop an image here": "Bild hierher ziehen",
 "Upload": "Hochladen",
+"Block": "Block",
+"Align": "Ausrichtung",
 "Default": "Standard",
 "Circle": "Kreis",
 "Disc": "Gef\u00fcllter Kreis",
@@ -75,6 +77,7 @@ tinymce.addI18n('de_AT',{
 "Source code": "Quelltext",
 "Insert\/Edit code sample": "Beispielcode einf\u00fcgen\/bearbeiten",
 "Language": "Sprache",
+"Code sample": "Code Beispiel",
 "Color": "Farbe",
 "R": "R",
 "G": "G",
@@ -105,6 +108,8 @@ tinymce.addI18n('de_AT',{
 "Premium plugins:": "Premium Plugins:",
 "Learn more...": "Mehr Informationen...",
 "You are using {0}": "Sie verwenden {0}",
+"Plugins": "Plugins",
+"Handy Shortcuts": "Praktische Abk\u00fcrzungen",
 "Horizontal line": "Horizontale Trennlinie",
 "Insert\/edit image": "Bild einf\u00fcgen\/bearbeiten",
 "Image description": "Bildbeschreibung",
@@ -242,6 +247,7 @@ tinymce.addI18n('de_AT',{
 "Show blocks": "Blockelemente einblenden",
 "Show invisible characters": "Unsichtbare Zeichen einblenden",
 "Words: {0}": "W\u00f6rter: {0}",
+"{0} words": "{0} W\u00f6rter",
 "File": "Datei",
 "Edit": "Bearbeiten",
 "Insert": "Einf\u00fcgen",
@@ -249,5 +255,6 @@ tinymce.addI18n('de_AT',{
 "Format": "Format",
 "Table": "Tabelle",
 "Tools": "Extras",
+"Powered by {0}": "Betrieben von {0}",
 "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr die Werkzeugleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe"
 });
\ No newline at end of file
