@@ -56,6 +56,8 @@ tinymce.addI18n('uk_UA',{
 "OR": "\u0410\u0411\u041e",
 "Drop an image here": "\u041f\u0435\u0440\u0435\u043c\u0456\u0441\u0442\u0456\u0442\u044c \u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u043d\u044f \u0441\u044e\u0434\u0438",
 "Upload": "\u0417\u0430\u0432\u0430\u043d\u0442\u0430\u0436\u0438\u0442\u0438",
+"Block": "\u0411\u043b\u043e\u043a",
+"Align": "Align",
 "Default": "\u0423\u043c\u043e\u0432\u0447\u0430\u043d\u043d\u044f",
 "Circle": "\u041a\u043e\u043b\u043e",
 "Disc": "\u0414\u0438\u0441\u043a",
@@ -75,6 +77,7 @@ tinymce.addI18n('uk_UA',{
 "Source code": "\u0414\u0436\u0435\u0440\u0435\u043b\u043e",
 "Insert\/Edit code sample": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u0438\/\u041d\u0430\u043f\u0438\u0441\u0430\u0442\u0438 \u043f\u0440\u0438\u043a\u043b\u0430\u0434 \u043a\u043e\u0434\u0443",
 "Language": "\u041c\u043e\u0432\u0430",
+"Code sample": "\u041f\u0440\u0438\u043a\u043b\u0430\u0434 \u043a\u043e\u0434\u0443",
 "Color": "\u041a\u043e\u043b\u0456\u0440",
 "R": "R",
 "G": "G",
@@ -105,6 +108,8 @@ tinymce.addI18n('uk_UA',{
 "Premium plugins:": "\u041f\u0440\u0435\u043c\u0456\u0430\u043b\u044c\u043d\u0456 \u0434\u043e\u0434\u0430\u0442\u043a\u0438:",
 "Learn more...": "\u0414\u043e\u0434\u0430\u0442\u043a\u043e\u0432\u043e...",
 "You are using {0}": "\u0423 \u0432\u0438\u043a\u043e\u0440\u0438\u0441\u0442\u0430\u043d\u043d\u0456 {0}",
+"Plugins": "\u041f\u043b\u0430\u0433\u0456\u043d\u0438",
+"Handy Shortcuts": "\u041a\u043e\u0440\u0438\u0441\u043d\u0456 \u044f\u0440\u043b\u0438\u043a\u0438",
 "Horizontal line": "\u0413\u043e\u0440\u0438\u0437\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u0430 \u043b\u0456\u043d\u0456\u044f",
 "Insert\/edit image": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u0438\/\u0440\u0435\u0434\u0430\u0433\u0443\u0432\u0430\u0442\u0438 \u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u043d\u044f",
 "Image description": "\u041e\u043f\u0438\u0441 \u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u043d\u044f",
@@ -232,7 +237,7 @@ tinymce.addI18n('uk_UA',{
 "Border color": "\u041a\u043e\u043b\u0456\u0440 \u043c\u0435\u0436\u0456",
 "Insert template": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u0438 \u0448\u0430\u0431\u043b\u043e\u043d",
 "Templates": "\u0428\u0430\u0431\u043b\u043e\u043d\u0438",
-"Template": "Template",
+"Template": "\u0422\u0435\u043c\u043f\u043b\u0435\u0442",
 "Text color": "\u041a\u043e\u043b\u0456\u0440 \u0442\u0435\u043a\u0441\u0442\u0443",
 "Background color": "\u041a\u043e\u043b\u0456\u0440 \u0444\u043e\u043d\u0443",
 "Custom...": "\u0406\u043d\u0448\u0438\u0439...",
@@ -242,6 +247,7 @@ tinymce.addI18n('uk_UA',{
 "Show blocks": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u0438 \u0431\u043b\u043e\u043a\u0438",
 "Show invisible characters": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u0438 \u043d\u0435\u0432\u0438\u0434\u0438\u043c\u0456 \u0441\u0438\u043c\u0432\u043e\u043b\u0438",
 "Words: {0}": "\u0421\u043b\u043e\u0432\u0430: {0}",
+"{0} words": "{0} \u0441\u043b\u0456\u0432",
 "File": "\u0424\u0430\u0439\u043b",
 "Edit": "\u041f\u0440\u0430\u0432\u043a\u0430",
 "Insert": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u0438",
@@ -249,5 +255,6 @@ tinymce.addI18n('uk_UA',{
 "Format": "\u0424\u043e\u0440\u043c\u0430\u0442",
 "Table": "\u0422\u0430\u0431\u043b\u0438\u0446\u044f",
 "Tools": "\u0406\u043d\u0441\u0442\u0440\u0443\u043c\u0435\u043d\u0442\u0438",
+"Powered by {0}": "\u0417\u0430 \u043f\u0456\u0434\u0442\u0440\u0438\u043c\u0438\u043a\u0438 {0}",
 "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "\u041e\u0431\u043b\u0430\u0441\u0442\u044c Rich \u0442\u0435\u043a\u0441\u0442\u0443. \u041d\u0430\u0442\u0438\u0441\u043d\u0456\u0442\u044c ALT-F9 - \u043c\u0435\u043d\u044e. \u041d\u0430\u0442\u0438\u0441\u043d\u0456\u0442\u044c ALT-F10 - \u043f\u0430\u043d\u0435\u043b\u044c \u0456\u043d\u0441\u0442\u0440\u0443\u043c\u0435\u043d\u0442\u0456\u0432. \u041d\u0430\u0442\u0438\u0441\u043d\u0456\u0442\u044c ALT-0 - \u0434\u043e\u0432\u0456\u0434\u043a\u0430"
 });
\ No newline at end of file
